/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY. The author is
 * not liable for any claims arising from secondary or illegal development.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.system.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.enums.ParameterIn;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import org.springblade.common.constant.CommonConstant;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.cache.utils.CacheUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tenant.annotation.NonDS;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.StringPool;
import org.springblade.system.pojo.entity.DictBiz;
import org.springblade.system.pojo.vo.DictBizVO;
import org.springblade.system.pojo.vo.RhzfZdVO;
import org.springblade.system.pojo.vo.ZdVO;
import org.springblade.system.service.IDictBizService;
import org.springblade.system.wrapper.DictBizWrapper;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

import static org.springblade.core.cache.constant.CacheConstant.DICT_CACHE;

/**
 * 控制器
 *
 * @author Chill
 */
@NonDS
@RestController
@AllArgsConstructor
@RequestMapping("/dict-biz")
@Tag(name = "业务字典", description = "业务字典")
public class DictBizController extends BladeController {

	private final IDictBizService dictService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description = "传入dict")
	public R<DictBizVO> detail(DictBiz dict) {
		DictBiz detail = dictService.getOne(Condition.getQueryWrapper(dict));
		return R.data(DictBizWrapper.build().entityVO(detail));
	}

	/**
	 * 列表
	 */
	@GetMapping("/list")
	@Parameters({
		@Parameter(name = "code", description = "字典编号", in = ParameterIn.QUERY, schema = @Schema(type = "string")),
		@Parameter(name = "dictValue", description = "字典名称", in = ParameterIn.QUERY, schema = @Schema(type = "string"))
	})
	@ApiOperationSupport(order = 2)
	@Operation(summary = "列表", description = "传入dict")
	public R<List<DictBizVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> dict) {
		List<DictBiz> list = dictService.list(Condition.getQueryWrapper(dict, DictBiz.class).lambda().orderByAsc(DictBiz::getSort));
		return R.data(DictBizWrapper.build().listNodeVO(list));
	}

	/**
	 * 顶级列表
	 */
	@GetMapping("/parent-list")
	@Parameters({
		@Parameter(name = "code", description = "字典编号", in = ParameterIn.QUERY, schema = @Schema(type = "string")),
		@Parameter(name = "dictValue", description = "字典名称", in = ParameterIn.QUERY, schema = @Schema(type = "string"))
	})
	@ApiOperationSupport(order = 3)
	@Operation(summary = "列表", description = "传入dict")
	public R<IPage<DictBizVO>> parentList(@Parameter(hidden = true) @RequestParam Map<String, Object> dict, Query query) {
		return R.data(dictService.parentList(dict, query));
	}

	/**
	 * 子列表
	 */
	@GetMapping("/child-list")
	@Parameters({
		@Parameter(name = "code", description = "字典编号", in = ParameterIn.QUERY, schema = @Schema(type = "string")),
		@Parameter(name = "dictValue", description = "字典名称", in = ParameterIn.QUERY, schema = @Schema(type = "string")),
		@Parameter(name = "parentId", description = "字典名称", in = ParameterIn.QUERY, schema = @Schema(type = "string"))
	})
	@ApiOperationSupport(order = 4)
	@Operation(summary = "列表", description = "传入dict")
	public R<List<DictBizVO>> childList(@Parameter(hidden = true) @RequestParam Map<String, Object> dict, @RequestParam(required = false, defaultValue = "-1") Long parentId) {
		return R.data(dictService.childList(dict, parentId));
	}

	/**
	 * 获取字典树形结构
	 */
	@GetMapping("/tree")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "树形结构", description = "树形结构")
	public R<List<DictBizVO>> tree() {
		List<DictBizVO> tree = dictService.tree();
		return R.data(tree);
	}

	/**
	 * 获取字典树形结构
	 */
	@GetMapping("/parent-tree")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "树形结构", description = "树形结构")
	public R<List<DictBizVO>> parentTree() {
		List<DictBizVO> tree = dictService.parentTree();
		return R.data(tree);
	}

	/**
	 * 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description = "传入dict")
	public R submit(@Valid @RequestBody DictBiz dict) {
		CacheUtil.clear(DICT_CACHE);
		return R.status(dictService.submit(dict));
	}


	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "删除", description = "传入ids")
	public R remove(@Parameter(description = "主键集合", required = true) @RequestParam String ids) {
		CacheUtil.clear(DICT_CACHE);
		return R.status(dictService.removeDict(ids));
	}

	/**
	 * 获取字典
	 */
	@GetMapping("/dictionary")
	@ApiOperationSupport(order = 8)
	@Operation(summary = "获取字典", description = "获取字典")
	public R<List<DictBiz>> dictionary(String code) {
		List<DictBiz> tree = dictService.getList(code);
		return R.data(tree);
	}

	/**
	 * 获取字典树
	 */
	@GetMapping("/dictionary-tree")
	@ApiOperationSupport(order = 9)
	@Operation(summary = "获取字典树", description = "获取字典树")
	public R<List<DictBizVO>> dictionaryTree(String code) {
		List<DictBiz> tree = dictService.getList(code);
		return R.data(DictBizWrapper.build().listNodeVO(tree));
	}

	/**
	 * 字典键值列表
	 */
	@GetMapping("/select")
	@ApiOperationSupport(order = 10)
	@Operation(summary = "字典键值列表", description = "字典键值列表")
	public R<List<DictBiz>> select() {
		List<DictBiz> list = dictService.list(Wrappers.<DictBiz>query().lambda().eq(DictBiz::getParentId, CommonConstant.TOP_PARENT_ID));
		list.forEach(dict -> dict.setDictValue(dict.getCode() + StringPool.COLON + StringPool.SPACE + dict.getDictValue()));
		return R.data(list);
	}

	/**
	 * 字典全列表
	 */
	@GetMapping("/select-all")
	@ApiOperationSupport(order = 11)
	@Operation(summary = "字典全列表", description = "字典全列表")
	public R<List<DictBiz>> selectAll() {
		List<DictBiz> list = dictService.list(Wrappers.<DictBiz>query().lambda().eq(DictBiz::getIsDeleted, BladeConstant.DB_NOT_DELETED));
		return R.data(list);
	}

	/**
	 * 获取字典
	 */
	@GetMapping("/dictionaryList")
	public R dictionaryList() {
		RhzfZdVO data = new RhzfZdVO();

		String code = "";
		code = "jwrylb"; // 境外人员类别
		List<ZdVO> jwrylb = dictService.getDictList(code);
		data.setJwrylb(jwrylb);
		code = "sfzjzl"; // 身份证件种类
		List<ZdVO> sfzjzl = dictService.getDictList(code);
		data.setSfzjzl(sfzjzl);
		code = "lhtjlsy"; // 来华停居留事由
		List<ZdVO> lhtjlsy = dictService.getDictList(code);
		data.setLhtjlsy(lhtjlsy);
		code = "yfzgx"; // 与房主关系
		List<ZdVO> yfzgx = dictService.getDictList(code);
		data.setYfzgx(yfzgx);
		code = "hyzk"; // 婚姻状况
		List<ZdVO> hyzk = dictService.getDictList(code);
		data.setHyzk(hyzk);
		code = "whcd"; // 文化程度
		List<ZdVO> whcd = dictService.getDictList(code);
		data.setWhcd(whcd);
		code = "zzmm"; // 政治面貌
		List<ZdVO> zzmm = dictService.getDictList(code);
		data.setZzmm(zzmm);
		code = "byzk"; // 兵役状况
		List<ZdVO> byzk = dictService.getDictList(code);
		data.setByzk(byzk);
		code = "dwlb"; // 单位类别
		List<ZdVO> dwlb = dictService.getDictList(code);
		data.setDwlb(dwlb);
		code = "gllb"; // 管理类别
		List<ZdVO> gllb = dictService.getDictList(code);
		data.setGllb(gllb);
		code = "glxl"; // 管理细类
		List<ZdVO> glxl = dictService.getDictList(code);
		data.setGlxl(glxl);
		code = "wlhrylb"; // 未落户人员类别
		List<ZdVO> wlhrylb = dictService.getDictList(code);
		data.setWlhrylb(wlhrylb);
		code = "hjdcxflsx"; // 户籍地城乡分类属性
		List<ZdVO> hjdcxflsx = dictService.getDictList(code);
		data.setHjdcxflsx(hjdcxflsx);
		code = "zzdcxflsx"; // 暂住地城乡分类属性
		List<ZdVO> zzdcxflsx = dictService.getDictList(code);
		data.setZzdcxflsx(zzdcxflsx);
		code = "gjdq"; // 国家地区
		List<ZdVO> gjdq = dictService.getDictList(code);
		data.setGjdq(gjdq);
		code = "tjlzjzl"; // 停居留证件种类
		List<ZdVO> tjlzjzl = dictService.getDictList(code);
		data.setTjlzjzl(tjlzjzl);
		code = "fwlb"; // 房屋类别
		List<ZdVO> fwlb = dictService.getDictList(code);
		data.setFwlb(fwlb);
		code = "fwxz"; // 房屋性质
		List<ZdVO> fwxz = dictService.getDictList(code);
		data.setFwxz(fwxz);
		code = "fwyt"; // 房屋用途
		List<ZdVO> fwyt = dictService.getDictList(code);
		data.setFwyt(fwyt);
		code = "syyt"; // 使用用途
		List<ZdVO> syyt = dictService.getDictList(code);
		data.setSyyt(syyt);
		code = "tsrq"; // 特殊人群
		List<ZdVO> tsrq = dictService.getDictList(code);
		data.setTsrq(tsrq);
		code = "zjxy"; // 宗教信仰
		List<ZdVO> zjxy = dictService.getDictList(code);
		data.setZjxy(zjxy);
		code = "mz"; // 民族
		List<ZdVO> mz = dictService.getDictList(code);
		data.setMz(mz);
		code = "zzsy"; // 暂住事由
		List<ZdVO> zzsy = dictService.getDictList(code);
		data.setZzsy(zzsy);
		code = "ldphhz"; // 楼栋牌号后缀
		List<ZdVO> ldphhz = dictService.getDictList(code);
		data.setLdphhz(ldphhz);

		code = "zzrkzxyy"; // 暂住人口注销原因
		List<ZdVO> zzrkzxyy = dictService.getDictList(code);
		data.setZzrkzxyy(zzrkzxyy);
		code = "czrkzxyy"; // 常住人口注销原因
		List<ZdVO> czrkzxyy = dictService.getDictList(code);
		data.setCzrkzxyy(czrkzxyy);
		code = "wcyy"; // 外出原因
		List<ZdVO> wcyy = dictService.getDictList(code);
		data.setWcyy(wcyy);
		code = "hzrbzyy"; // 户在人不在原因
		List<ZdVO> hzrbzyy = dictService.getDictList(code);
		data.setHzrbzyy(hzrbzyy);
		code = "gsjyms"; // 公司经营模式
		List<ZdVO> gsjyms = dictService.getDictList(code);
		data.setGsjyms(gsjyms);
		code = "gsrcjyqk"; // 公司日常经营情况
		List<ZdVO> gsrcjyqk = dictService.getDictList(code);
		data.setGsrcjyqk(gsrcjyqk);
		code = "zylb"; // 职业类别
		List<ZdVO> zylb = dictService.getDictList(code);
		data.setZylb(zylb);
		code = "jyfs"; // 经营方式
		List<ZdVO> jyfs = dictService.getDictList(code);
		data.setJyfs(jyfs);

		code = "djclqk"; // 涉稳重点人--打击处理情况
		List<ZdVO> djclqk = dictService.getDictList(code);
		data.setClqk(djclqk);
		code = "djjg"; // 涉稳重点人--打击结果
		List<ZdVO> djjg = dictService.getDictList(code);
		data.setDjjg(djjg);
		return R.data(data);
	}

	@GetMapping("dictionaryCode")
	public R dictionaryCode(String code) {
		List<ZdVO> list = dictService.getDictList(code);
		return R.data(list);
	}
}
