package org.springblade.swzdr.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.constant.RoleConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.swzdr.excel.RyRwzlExcel;
import org.springblade.swzdr.pojo.entity.RyInfoEntity;
import org.springblade.swzdr.pojo.entity.RyRwzlEntity;
import org.springblade.swzdr.pojo.vo.RyRwzlVO;
import org.springblade.swzdr.service.IRyInfoService;
import org.springblade.swzdr.service.IRyRwzlService;
import org.springblade.swzdr.wrapper.RyRwzlWrapper;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * 人员_任务指令(接收/转递) 控制器
 *
 * @author BladeX
 * @since 2024-10-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-ryRwzl/ryRwzl")
@Tag(name = "人员_任务指令(接收/转递)", description = "人员_任务指令(接收/转递)接口")
public class RyRwzlController extends BladeController {

	private final IRyRwzlService ryRwzlService;

	private final IRyInfoService ryInfoService;

	/**
	 * 人员_任务指令(接收/转递) 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入ryRwzl")
	public R<RyRwzlVO> detail(RyRwzlEntity ryRwzl) {
		RyRwzlEntity detail = ryRwzlService.getOne(Condition.getQueryWrapper(ryRwzl));
		return R.data(RyRwzlWrapper.build().entityVO(detail));
	}

	/**
	 * 人员_任务指令(接收/转递) 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入ryRwzl")
	public R<IPage<RyRwzlVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> ryRwzl, Query query) {
		IPage<RyRwzlEntity> pages = ryRwzlService.page(Condition.getPage(query), Condition.getQueryWrapper(ryRwzl, RyRwzlEntity.class));
		return R.data(RyRwzlWrapper.build().pageVO(pages));
	}

	/**
	 * 人员_任务指令(接收/转递) 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入ryRwzl")
	public R<IPage<RyRwzlVO>> page(@RequestParam Map<String, String> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId().split(",")[0]);
		IPage<RyRwzlVO> pages = ryRwzlService.selectRyRwzlPage(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 人员_任务指令(接收/转递) 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入ryRwzl")
	public R save(@Valid @RequestBody RyRwzlEntity ryRwzl) {
		return R.status(ryRwzlService.save(ryRwzl));
	}

	/**
	 * 人员_任务指令(接收/转递) 修改
	 */
	@Transactional
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入ryRwzl")
	public R update(@Valid @RequestBody RyRwzlEntity ryRwzl) {
		ryRwzlService.updateById(ryRwzl);
		if (ryRwzl.getZt() == 2) {
			// 转递时，修改swzdr_ry_info表的pcs_id
			RyInfoEntity ryInfoEntity = new RyInfoEntity();
			ryInfoEntity.setId(ryRwzl.getRyId());
			ryInfoEntity.setPcsId(ryRwzl.getZdPcsId());
			ryInfoService.updateById(ryInfoEntity);
		}
		return R.status(true);
	}

	/**
	 * 人员_任务指令(接收/转递) 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入ryRwzl")
	public R submit(@Valid @RequestBody RyRwzlEntity ryRwzl) {
		return R.status(ryRwzlService.saveOrUpdate(ryRwzl));
	}

	/**
	 * 人员_任务指令(接收/转递) 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(name = "主键集合", required = true) @RequestParam String ids) {
		return R.status(ryRwzlService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-ryRwzl")
	@ApiOperationSupport(order = 9)
	@Operation(summary = "导出数据", description  = "传入ryRwzl")
	public void exportRyRwzl(@Parameter(hidden = true) @RequestParam Map<String, Object> ryRwzl, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RyRwzlEntity> queryWrapper = Condition.getQueryWrapper(ryRwzl, RyRwzlEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RyRwzl::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RyRwzlEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RyRwzlExcel> list = ryRwzlService.exportRyRwzl(queryWrapper);
		ExcelUtil.export(response, "人员_任务指令(接收/转递)数据" + DateUtil.time(), "人员_任务指令(接收/转递)数据表", list, RyRwzlExcel.class);
	}

}
