package org.springblade.swzdr.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.constant.RoleConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.swzdr.excel.RyXsExcel;
import org.springblade.swzdr.pojo.entity.RyXsEntity;
import org.springblade.swzdr.pojo.vo.RyInfoVO;
import org.springblade.swzdr.pojo.vo.RyXsVO;
import org.springblade.swzdr.service.IRyXsService;
import org.springblade.swzdr.wrapper.RyXsWrapper;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * 人员_写实记录 控制器
 *
 * @author BladeX
 * @since 2024-09-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-ryXs/ryXs")
@Tag(name = "人员_写实记录", description = "人员_写实记录接口")
public class RyXsController extends BladeController {

	private final IRyXsService ryXsService;

	/**
	 * 人员_写实记录 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入ryXs")
	public R<RyXsVO> detail(RyXsEntity ryXs) {
		RyXsEntity detail = ryXsService.getOne(Condition.getQueryWrapper(ryXs));
		return R.data(RyXsWrapper.build().entityVO(detail));
	}
	/**
	 * 人员_写实记录 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入ryXs")
	public R<IPage<RyXsVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> ryXs, Query query) {
		IPage<RyXsEntity> pages = ryXsService.page(Condition.getPage(query), Condition.getQueryWrapper(ryXs, RyXsEntity.class));
		return R.data(RyXsWrapper.build().pageVO(pages));
	}

	/**
	 * 人员_写实记录 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description = "传入ryXs")
	public R page(@RequestParam Map<String, String> params, Query query) {
		params.put("userId", AuthUtil.getUserId().toString());
		IPage<RyInfoVO> pages = ryXsService.selectRyXsPage(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 人员_写实记录 根据人员id查询
	 */
	@GetMapping("/getListByRyId")
	public R getListByRyId(Long ryId) {
		List<RyXsVO> ryXsVO = ryXsService.getXsList(ryId);
		return R.data(ryXsVO);
	}

	/**
	 * 人员_写实记录 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入ryXs")
	public R save(@Valid @RequestBody RyXsEntity ryXs) {
		return R.status(ryXsService.save(ryXs));
	}

	/**
	 * 人员_写实记录 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入ryXs")
	public R update(@Valid @RequestBody RyXsEntity ryXs) {
		return R.status(ryXsService.updateById(ryXs));
	}

	/**
	 * 人员_写实记录 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入ryXs")
	public R submit(@Valid @RequestBody RyXsEntity ryXs) {
		return R.status(ryXsService.saveOrUpdate(ryXs));
	}

	/**
	 * 人员_写实记录 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(name = "主键集合", required = true) @RequestParam String ids) {
		return R.status(ryXsService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-ryXs")
	@ApiOperationSupport(order = 9)
	@Operation(summary = "导出数据", description  = "传入ryXs")
	public void exportRyXs(@Parameter(hidden = true) @RequestParam Map<String, Object> ryXs, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RyXsEntity> queryWrapper = Condition.getQueryWrapper(ryXs, RyXsEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RyXs::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RyXsEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RyXsExcel> list = ryXsService.exportRyXs(queryWrapper);
		ExcelUtil.export(response, "人员_写实记录数据" + DateUtil.time(), "人员_写实记录数据表", list, RyXsExcel.class);
	}

}
