package org.springblade.swzdr.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.constant.RoleConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.swzdr.excel.RySpExcel;
import org.springblade.swzdr.pojo.entity.RyDjspEntity;
import org.springblade.swzdr.pojo.entity.RyInfoEntity;
import org.springblade.swzdr.pojo.vo.RyDjspVO;
import org.springblade.swzdr.service.IRyDjspService;
import org.springblade.swzdr.service.IRyInfoService;
import org.springblade.swzdr.wrapper.RySpWrapper;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * 人员_审批历史表 控制器
 *
 * @author BladeX
 * @since 2024-09-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-rySp/rySp")
@Tag(name = "人员_审批历史表", description = "人员_审批历史表接口")
public class SwzdrRySpController extends BladeController {

	private final IRyDjspService rySpService;

	private final IRyInfoService ryInfoService;

	/**
	 * 人员_审批历史表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入rySp")
	public R<RyDjspVO> detail(RyDjspEntity rySp) {
		RyDjspEntity detail = rySpService.getOne(Condition.getQueryWrapper(rySp));
		return R.data(RySpWrapper.build().entityVO(detail));
	}

	/**
	 * 人员_审批历史表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入rySp")
	public R<IPage<RyDjspVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> rySp, Query query) {
		IPage<RyDjspEntity> pages = rySpService.page(Condition.getPage(query), Condition.getQueryWrapper(rySp, RyDjspEntity.class));
		return R.data(RySpWrapper.build().pageVO(pages));
	}

	/**
	 * 人员_审批历史表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入rySp")
	public R<IPage<RyDjspVO>> page(@RequestParam Map<String, String> params, Query query) {
		params.put("userId", AuthUtil.getUserId().toString());
		params.put("deptId", AuthUtil.getDeptId().split(",")[0]);
		IPage<RyDjspVO> pages = rySpService.selectRySpPage(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 人员_等级变更记录 根据人员id查询
	 */
	@GetMapping("/getListByRyId")
	public R page(Long ryId) {
		List<RyDjspVO> djspList = rySpService.getDjspList(ryId);
		return R.data(djspList);
	}

	/**
	 * 人员_审批历史表 新增 fsgxhs  fsggssx
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入rySp")
	public R save(@Valid @RequestBody RyDjspEntity rySp) {
		QueryWrapper<RyDjspEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("is_deleted", 0);
		queryWrapper.eq("user_id", rySp.getUserId());
		queryWrapper.eq("spjg", 0);
		RyDjspEntity rySpEntity = rySpService.getOne(queryWrapper);
		if (null != rySpEntity) {
			return R.fail("存在未审批的等级变更，请勿重复提交");
		}
		return R.status(rySpService.save(rySp));
	}

	/**
	 * 人员_审批历史表 修改
	 */
	@Transactional
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入rySp")
	public R update(@Valid @RequestBody RyDjspEntity rySp) {
		rySpService.updateById(rySp);
		if (rySp.getSpjg() == 1) {
			// 审批通过，修改ry_info表的level
			RyInfoEntity ryInfoEntity = new RyInfoEntity();
			ryInfoEntity.setId(rySp.getUserId());
			ryInfoEntity.setLevel(rySp.getTargetLevel());
			ryInfoService.updateById(ryInfoEntity);
		}
		return R.status(true);
	}

	/**
	 * 人员_审批历史表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入rySp")
	public R submit(@Valid @RequestBody RyDjspEntity rySp) {
		return R.status(rySpService.saveOrUpdate(rySp));
	}

	/**
	 * 人员_审批历史表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(name = "主键集合", required = true) @RequestParam String ids) {
		return R.status(rySpService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-rySp")
	@ApiOperationSupport(order = 9)
	@Operation(summary = "导出数据", description  = "传入rySp")
	public void exportRySp(@Parameter(hidden = true) @RequestParam Map<String, Object> rySp, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RyDjspEntity> queryWrapper = Condition.getQueryWrapper(rySp, RyDjspEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RySp::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RyDjspEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RySpExcel> list = rySpService.exportRySp(queryWrapper);
		ExcelUtil.export(response, "人员_审批历史表数据" + DateUtil.time(), "人员_审批历史表数据表", list, RySpExcel.class);
	}

}
